<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=en
// ** ne pas modifier le fichier **

return [

	// F
	'forum_description' => 'SPIP’s forum (private and public)',
	'forum_slogan' => 'Management of private and public forums in SPIP',
];
